=======
Credits
=======

Development Lead
----------------

* Henrik Blidh <henrik.blidh@nedomkull.com>

Contributors (sorted alphabetically)
------------------------------------

* `Jonas Böer <https://github.com/morgil>`_ (Kinemic GmbH)
    - Magnetometer module

* `Thibaud Mathieu <https://github.com/enlight3d>`_
    - Raw example for temperature module

* `m-georgi <https://github.com/m-georgi>`_
    - Sensor fusion module

* `Eric Tsai <https://github.com/scaryghost>`_ (mbientlab)
    - 64-bit datasignal address handling and typecasting
